@@ -10,7 +10,7 @@ class PDF::DAO::Array
 
     use PDF::DAO::Util :from-ast, :to-ast;
 
-    our %obj-cache = (); #= to catch circular references
+    our %seen = (); #= to catch circular references
 
     multi method new(Array $array!, |c) {
 	self.new( :$array, |c );
@@ -18,9 +18,9 @@ class PDF::DAO::Array
 
     multi method new(Array :$array = [], *%etc) {
         my Str $id = ~$array.WHICH;
-        my $obj = %obj-cache{$id};
+        my $obj = %seen{$id};
         unless $obj.defined {
-            temp %obj-cache{$id} = $obj = self.bless(|%etc);
+            temp %seen{$id} = $obj = self.bless(|%etc);
 	    $obj.tie-init;
             # this may trigger cascading PDF::DAO::Tie coercians
             # e.g. native Array to PDF::DAO::Array
